See ecr::mutGauss. Allows a vector of standard deviations. Scales
standard deviations to the range of [lower, upper].
mutGaussScaled(ind, p = 1, sdev = 0.05, lower, upper)[numeric] mutated individual.
[numeric]
Numeric vector / individual to mutate.
[numeric(1)]
Probability of mutation for the gauss mutation operator.
[numeric] standard deviation(s) of the Gauss mutation.
[numeric]
Vector of minimal values for each parameter of the decision space.
[numeric]
Vector of maximal values for each parameter of the decision space.
Other operators:
mutDoubleGeom(),
mutGaussIntScaled(),
mutGaussInt(),
mutPolynomialInt(),
mutRandomChoice(),
mutUniformInt(),
recGaussian(),
recIntIntermediate(),
recIntSBX()