Rank individuals by nondominating sorted front first and by hypervolume contribution or crowding distance second.
Ties are broken randomly by adding random noise of relative magnitude
.Machine$double.eps * 2^10 to points.
overallRankMO(fitness, sorting = "crowding", ref.point)[integer] vector of ranks with length ncol(fitness), lower ranks are
associated with individuals that tend to dominate more points and that tend to
have larger crowding distance or hypervolume contribution.
[matrix] fitness matrix, one column per individual.
[character(1)] one of "domhv" or "crowding" (default).
[numeric] reference point for hypervolume, must be given
if sorting is "domhv".