Gaussian intermediate recombinator samples component-wise from a normal distribution with mean as the component-wise mean and standard deviation as halved components-wise absolute distance of the two given parents. It is applicable only for numeric representations.
See also ecr::recIntermediate.
recGaussian(inds, lower, upper)[list of numeric] recombined individuals.
[list of numeric] list of two individuals to recombinate.
[numeric] lower bounds of inds values. May have same length as
one individual or may be a single number, if the lower bounds are the same for all
values.
[numeric] upper bounds of inds values. May have same length as
one individual or may be a single number, if the upper bounds are the same for all
values.
Other operators:
mutDoubleGeom(),
mutGaussIntScaled(),
mutGaussInt(),
mutGaussScaled(),
mutPolynomialInt(),
mutRandomChoice(),
mutUniformInt(),
recIntIntermediate(),
recIntSBX()